km3pipe.io.EvtPump
==================

.. currentmodule:: km3pipe.io

.. autoclass:: EvtPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EvtPump.__init__
      ~EvtPump.add
      ~EvtPump.close
      ~EvtPump.close_file
      ~EvtPump.configure
      ~EvtPump.expose
      ~EvtPump.extract_header
      ~EvtPump.finish
      ~EvtPump.get
      ~EvtPump.get_blob
      ~EvtPump.next
      ~EvtPump.open_file
      ~EvtPump.pre_finish
      ~EvtPump.prepare_blobs
      ~EvtPump.process
      ~EvtPump.require
      ~EvtPump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~EvtPump.name
   
   